-- The functions and variables in this file are only for use in the mod itself.
-- Those that do real work should be local and wrapped in public functions

local function say(text)
    if yl_template.debug then
        core.log("action", "[MOD] yl_template : " .. text)
    end
end

local function get_savepath()
    local savepath = yl_template.worldpath .. yl_template.settings.save_path
    say("get_savepath : " .. dump(savepath))
    return savepath
end

local function get_filepath(filename)
    local path_to_file = get_savepath() .. DIR_DELIM .. filename .. ".json"
    say("get_filepath : " .. dump(filename) .. ":" .. dump(path_to_file))
    return path_to_file
end

local function save_json(filename, content)
    if type(filename) ~= "string" or type(content) ~= "table" then
        return false
    end
    local savepath = get_filepath(filename)
    local savecontent = minetest.write_json(content)
    return minetest.safe_file_write(savepath, savecontent)
end

local function load_json(path)
    local file = io.open(path, "r")
    if not file then return false, "Error opening file: " .. path end

    local content = file:read("*all")
    file:close()

    if not content then return false, "Error reading file: " .. path end

    return true, minetest.parse_json(content)
end

-- Public functions wrap the private ones, so they can be exchanged easily

function yl_template.load(filename, ...) return load_json(filename, ...) end

function yl_template.save(filename, content, ...)
    return save_json(filename, content, ...)
end
